--- title: "wallaroo.utils" type: docs linkTitle: "wallaroo.utils" ---
def is_arrow_enabled():
def is_models_enabled():
def flatten_np_array_columns(df, col):
def convert_ndarray_batch_to_arrow(arr):
def generate_file_name(directory: str, file_prefix: str, file_num: int, file_suffix: str) -> str:
def create_new_arrow_file( directory: str, file_num: int, file_prefix: str, file_suffix: str, schema: pyarrow.lib.Schema) -> pyarrow.ipc.RecordBatchFileWriter:
def create_new_json_file( directory: str, file_num: int, file_prefix: str, file_suffix: str) -> <class 'TextIO'>:
def create_new_file( directory: str, file_num: int, file_prefix: str, schema: Optional[pyarrow.lib.Schema] = None, arrow: Optional[bool] = False) -> Union[pyarrow.ipc.RecordBatchFileWriter, TextIO]:
def write_to_file( record_batch: pyarrow.lib.RecordBatch, writer: Union[pyarrow.ipc.RecordBatchFileWriter, TextIO], arrow: Optional[bool] = False) -> None: